/*
 * GameParseException.java
 * 
 * Created on October 22, 2001, 8:54 AM
 */
package games.strategy.engine.data;

/**
 * 
 * @author Sean Bridges
 * @version 1.0
 */
@SuppressWarnings("serial")
public class GameParseException extends Exception
{
	public GameParseException(final String error)
	{
		super(error);
	}
}
